# -*- coding: utf-8 -*-

from django.test import TestCase
from django_envie.workroom import convertfiletovars

import os


class DjangoEnvieTestCase(TestCase):
    def test_convertfiletovars(self):
        filepath = os.path.join('.env.py')
        with open(filepath, 'w+') as f:
            f.write('SECRET_KEY = "Not so secret"')
        convertfiletovars()
        secret_key = os.getenv('SECRET_KEY')
        self.assertEqual(secret_key, 'Not so secret')
        os.remove(filepath)
        del os.environ['SECRET_KEY']

    def test_convertfiletovars_env_file_outside_project(self):
        filepath = os.path.join('..', '.env.yml')
        with open(filepath, 'w+') as f:
            f.write('secret_key : "Not so secret"\r\nmy_name : "Oluwafemi"')
        convertfiletovars(fileext='yml')
        secret_key = os.getenv('secret_key')
        self.assertEqual(secret_key, 'Not so secret')
        tmp_path = os.path.dirname(os.path.realpath(__file__))
        os.remove(os.path.join(tmp_path, '..', '..', '.env.yml'))



from re import search
import os


def convertfiletovars(fileext='py'):
    """
    Set environment variables from .env.py
    if it exists in the project dir.
    """

    filepath = os.path.join(os.getcwd(), '.env.'+fileext)
    if not os.path.isfile(filepath):
        # Backtrack to root directory
        os.chdir('..')
        filepath = os.path.join('.env.'+fileext)
    if os.path.isfile(filepath):
        if fileext == 'py':
            try:
                with open(filepath, 'r') as env_file:
                    for setting in env_file:
                        match = search("(\w+)\s=\s\"(.*?)\"", setting)
                        env_var, config = match.groups()
                        os.environ[env_var] = config
            except:
                print "No .env.py environment file found in your project directory.\
                Go ahead and create one."
        elif fileext == 'yml':
            from yaml import load
            try:
                environ_data = load(file(filepath, 'r'))
                for key, value in environ_data.iteritems():
                    os.environ[key] = value
            except:
                print "No .env.yaml environment file found in your project directory.\
                Go ahead and create one."
